/// <reference types="react" />
import * as React from 'react';
export interface SelectedType {
    rowIdx: number;
    idx: number;
}
export interface ColumnEvent {
    name: string;
    rowIdx: number;
    idx: number;
}
export interface DraggedType {
    idx: number;
    rowIdx: number;
    value: string;
}
export interface RowUpdateEvent {
    keyCode: string;
    changed: {
        expandedHeight: number;
    };
    rowIdx: number;
}
export interface Props {
    rowHeight?: number;
    headerRowHeight?: number;
    headerFiltersHeight?: number;
    minHeight: number;
    minWidth?: number;
    enableRowSelect?: any;
    onRowUpdated?: Function;
    rowGetter: Function;
    rowsCount: number;
    toolbar?: any;
    enableCellSelect?: boolean;
    columns: any;
    onFilter?: Function;
    onCellCopyPaste?: Function;
    onCellsDragged?: Function;
    onAddFilter?: any;
    onGridSort?: Function;
    onDragHandleDoubleClick?: Function;
    onGridRowsUpdated?: Function;
    onRowSelect?: Function;
    rowKey?: string;
    rowScrollTimeout?: number;
    onClearFilters?: Function;
    contextMenu?: any;
    cellNavigationMode?: 'none' | 'loopOverRow' | 'changeRow';
    onCellSelected?: Function;
    onCellDeSelected?: Function;
    onCellExpand?: Function;
    enableDragAndDrop?: boolean;
    onRowExpandToggle?: Function;
    draggableHeaderCell?: Function;
    getValidFilterValues?: Function;
    rowSelection?: any;
    onRowClick?: Function;
    onGridKeyUp?: Function;
    onGridKeyDown?: Function;
    rowRenderer?: any;
    emptyRowsView?: any;
    rowGroupRenderer?: Function;
    rowActionsCell?: Function;
    onCheckCellIsEditable?: Function;
    overScan?: any;
    onDeleteSubRow?: any;
    onAddSubRow?: Function;
}
declare class ReactDataGrid extends React.Component<Props, any> {
    static defaultProps: Partial<Props>;
    base: any;
    _gridNode: any;
    row: any;
    filterRow: any;
    selectAllCheckbox: any;
    _cachedColumns: any;
    _cachedComputedColumns: any;
    constructor(props: Props);
    getInitState(): {
        columnMetrics: any;
        selectedRows: never[];
        copied: null;
        expandedRows: never[];
        canFilter: boolean;
        columnFilters: {};
        sortDirection: null;
        sortColumn: null;
        dragged: null;
        scrollOffset: number;
        lastRowIdxUiSelected: number;
        selected: {};
    };
    hasSelectedCellChanged(selected: SelectedType): boolean;
    onContextMenuHide(): void;
    onColumnEvent(ev: any, columnEvent: ColumnEvent): void;
    onSelect(selected: SelectedType): void;
    onCellClick(cell: SelectedType): void;
    onCellContextMenu(cell: SelectedType): void;
    onCellDoubleClick(cell: SelectedType): void;
    onViewportDoubleClick(): void;
    onPressArrowUp(e: any): void;
    onPressArrowDown(e: any): void;
    onPressArrowLeft(e: any): void;
    onPressArrowRight(e: any): void;
    onPressTab(e: any): void;
    onPressEnter(e: any): void;
    onPressDelete(e: any): void;
    onPressEscape(e: any): void;
    onPressBackspace(e: any): void;
    onPressChar(e: any): void;
    onPressKeyWithCtrl(e: any): void;
    onGridRowsUpdated(cellKey: any, fromRow: any, toRow: any, updated: any, action: any, originRow: any): void;
    onCellCommit(commit: any): void;
    onDragStart(e: any): void;
    onToggleFilter(): void;
    onDragHandleDoubleClick(e: any): void;
    onCellExpand(args: any): void;
    onRowExpandToggle(args: any): void;
    isCellWithinBounds({idx, rowIdx}: any): boolean;
    handleDragStart(dragged: any): void;
    handleDragEnd(): void;
    handleDragEnter(row: any): void;
    handleTerminateDrag(): void;
    handlePaste(): void;
    handleCancelCopy(): void;
    handleCopy(args: {
        value: string;
    }): void;
    handleSort(columnKey: string, direction: any): void;
    getSelectedRow(rows: any, key: any): any;
    useNewRowSelection(): any;
    handleShiftSelect(rowIdx: any): boolean;
    handleNewRowSelect(rowIdx: any, rowData: any): void;
    handleRowSelect(rowIdx: number, columnKey: string, rowData: any, e: Event): void;
    handleCheckboxChange(e: any): void;
    getScrollOffSet(): void;
    getRowOffsetHeight(): number;
    getHeaderRows(): Array<{
        ref: Function;
        height: number;
    }>;
    getInitialSelectedRows(): boolean[];
    getRowSelectionProps(): any;
    getSelectedRows(): any;
    getSelectedValue(): string;
    moveSelectedCell(e: any, rowDelta: number, cellDelta: number): void;
    getNbrColumns(): any;
    getDataGridDOMNode(): any;
    calculateNextSelectionPosition(cellNavigationMode: string, cellDelta: number, rowDelta: number): {
        idx: any;
        rowIdx: any;
    };
    isAtLastCellInRow(nbrColumns: any): boolean;
    isAtLastRow(): boolean;
    isAtFirstCellInRow(): boolean;
    isAtFirstRow(): boolean;
    openCellEditor(rowIdx: any, idx: any): void;
    scrollToColumn(colIdx: any): void;
    setActive(keyPressed: string): void;
    setInactive(): void;
    isActive(): boolean;
    setupGridColumns(): any;
    copyPasteEnabled(): boolean;
    dragEnabled(): boolean;
    renderToolbar(): React.SFCElement<{
        columns: any;
        onToggleFilter: () => void;
        numberOfRows: number;
    }> | undefined;
    render(): JSX.Element;
}
export default ReactDataGrid;
